@@ -14,9 +14,11 @@ urlpatterns = patterns(  # pylint: disable=C0103
     '',
     url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
     url(r'^admin/', include(admin.site.urls)), 
-    (r'^jsi18n/$', 'django.views.i18n.javascript_catalog',
-     {'packages': ('pythonnest', 'django.contrib.admin', ), }),
-    (r'^' + MEDIA_PATH + '(?P<path>.*)$', 'django.views.static.serve', {'document_root': settings.MEDIA_ROOT}),
+    (r'^jsi18n/$', 'django.views.i18n.javascript_catalog', {'packages': ('pythonnest', 'django.contrib.admin', ), }),
+    (r'^' + settings.MEDIA_URL[1:] + '(?P<path>.*)$', 'pythonnest.views.static_serve',
+     {'document_root': settings.MEDIA_ROOT}),
+    (r'^' + settings.STATIC_URL[1:] + '(?P<path>.*)$', 'pythonnest.views.static_serve',
+     {'document_root': settings.STATIC_ROOT}),
     url(r'^pypi/(?P<package_name>[^/]+)/json$', 'pythonnest.views.package_json'),
     url(r'^pypi/(?P<package_name>[^/]+)/(?P<version>[^/]+)/json$', 'pythonnest.views.version_json'),
     url(r'^pypi/?$', 'rpc4django.views.serve_rpc_request'),
